@@ -1,4 +1,4 @@
-__version__ = '2011.09.06.4'
+__version__ = '2011.09.07.1'
 
 from datetime import date
 import logging
@@ -47,6 +47,10 @@ if logging_folder:
 
         def flush(self):
             pass
+
+        def isatty(self):
+            return False
+
     # Redirect Fabric output to log file.
     sys.stdout = StreamLogger()
     sys.stderr = StreamLogger(level=logging.ERROR)
